import { forwardRef, useCallback, useRef, useMemo } from 'react';
import useControlledState from '@s-ui/react-hooks/lib/useControlledState';
import loadable from '@loadable/component';
import PropTypes from 'prop-types';
import cx from 'classnames';
import UAParser from 'ua-parser-js';
import useIntersection from 'react-use/lib/useIntersection';
import { BASE_CLASS, CLASS_INNER, CLASS_ARROW, PREFIX_PLACEMENT, CLASS_TARGET, COLORS, PLACEMENTS, DEFAULT_OFFSET, TRIGGERS } from './config';
import TooltipExtendChildren from './TooltipExtendChildren';
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var Tooltip = loadable(function () {
  return import('reactstrap/lib/Tooltip');
}, {
  ssr: true
});
var AtomTooltip = /*#__PURE__*/forwardRef(function (_ref, forwardedRef) {
  var children = _ref.children,
      color = _ref.color,
      content = _ref.content,
      defaultIsVisible = _ref.defaultIsVisible,
      delay = _ref.delay,
      _ref$isArrowed = _ref.isArrowed,
      isArrowed = _ref$isArrowed === void 0 ? true : _ref$isArrowed,
      isVisible = _ref.isVisible,
      onToggle = _ref.onToggle,
      onOpen = _ref.onOpen,
      onClose = _ref.onClose,
      placement = _ref.placement,
      trigger = _ref.trigger;

  var _useControlledState = useControlledState(isVisible, defaultIsVisible),
      isVisibleState = _useControlledState[0],
      setIsVisibleState = _useControlledState[1];

  var toggleHandler = useCallback(function (event) {
    var newState = !isVisibleState;
    newState ? typeof onOpen === 'function' && onOpen(event, {
      isVisible: newState
    }) : typeof onClose === 'function' && onClose(event, {
      isVisible: newState
    });
    setIsVisibleState(newState);
    typeof onToggle === 'function' && onToggle(event, {
      isVisible: newState
    });
  }, [setIsVisibleState, isVisibleState, onOpen, onClose, onToggle]);
  var childrenRef = useRef();
  var deviceType = useMemo(function () {
    return trigger !== undefined && new UAParser(navigator.userAgent).getDevice().type;
  }, [trigger]);
  var intersection = useIntersection(childrenRef, {
    threshold: 0
  });
  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [/*#__PURE__*/_jsx(TooltipExtendChildren, {
      ref: childrenRef,
      className: CLASS_TARGET,
      children: children
    }), intersection && intersection.isIntersecting && /*#__PURE__*/_jsx(Tooltip, {
      arrowClassName: CLASS_ARROW,
      className: cx(BASE_CLASS, color && BASE_CLASS + "--" + color + "Color"),
      delay: delay,
      hideArrow: !isArrowed,
      innerClassName: CLASS_INNER,
      innerRef: forwardedRef,
      isOpen: isVisibleState,
      offset: DEFAULT_OFFSET,
      placement: placement,
      placementPrefix: PREFIX_PLACEMENT,
      target: childrenRef,
      toggle: toggleHandler,
      trigger: trigger || (['mobile', 'tablet'].includes(deviceType) ? 'legacy' : 'hover'),
      children: content
    })]
  });
});
AtomTooltip.displayName = 'AtomTooltip';
export default AtomTooltip;